==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtbestHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "selection of best records"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "attribute list"
#define KEYC "an attribute list for which enumeration is performed (when -k is omitted, all lines are assumed to take the same key value)"

/*-s*/
#define SRTT "a list of attrbutes whose value determines the ordering of records having the same key value"
#define SRTC "this specifies the list of attributes whose values determines the ordering of records having the same key value"
#define SRTF "numerical order, reverse order"

/*-R*/
#define RNGT "list of intervals of line numbers"
#define RNGC "specify the lines targeted"

/*-r*/
#define REVT "negate the condition"
#define REVC "select the lines other than those specified by -R"

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "For the attribute specified by -k, this command selects lines specified by -R."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbest -R 100 -i dat.xt -o rsl.xt\n\
xtbest -R 51_100 -i dat.xt -o rsl.xt\n\
xtbest -k date R 1,2,3 -i dat.xt -o rsl.xt\n\
xtbest -R MIN_10,20_MAX -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtuniq"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/en/xtbestHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "selection of best records"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "attribute list"
#define KEYC "an attribute list for which enumeration is performed (when -k is omitted, all lines are assumed to take the same key value)"

/*-s*/
#define SRTT "a list of attrbutes whose value determines the ordering of records having the same key value"
#define SRTC "this specifies the list of attributes whose values determines the ordering of records having the same key value"
#define SRTF "numerical order, reverse order"

/*-R*/
#define RNGT "list of intervals of line numbers"
#define RNGC "specify the lines targeted"

/*-r*/
#define REVT "negate the condition"
#define REVC "select the lines other than those specified by -R"

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command selects the first N records in order from the data set with respect to the key attribute -k as the unit for selection, where N is the number of records to be returned which is defined by the parameter -R. If -k is not specified, the selection will be based upon all records in the data. Data must be sorted by the key attribute with xtsort prior to xtbest command in order for the ranking to be listed correctly."

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtbest -R 100 -i dat.xt -o rsl.xt\n\
xtbest -R 51_100 -i dat.xt -o rsl.xt\n\
xtbest -k date R 1,2,3 -i dat.xt -o rsl.xt\n\
xtbest -R MIN_10,20_MAX -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtuniq"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
